.umap-dialog {
    z-index: 10001;
    margin: auto;
    margin-top: 100px;
    width: 40vw;
    max-width: 100vw;
    max-height: 50vh;
    padding: 20px;
    border: 1px solid #222;
    background-color: var(--background-color);
    color: var(--text-color);
    border-radius: 5px;
    overflow-y: auto;
}
.umap-dialog .umap-close-link {
    float: right;
    width: 100px;
}
